cdrouter
========

.. image:: https://img.shields.io/pypi/v/cdrouter.svg
    :target: https://pypi.python.org/pypi/cdrouter

Simple Python wrapper for the CDRouter Web
API. https://support.qacafe.com/cdrouter-web-api/

For more information on CDRouter, please visit http://www.qacafe.com/.

Installing
==========

cdrouter is available on PyPI.

.. code-block:: bash

    $ pip install -U cdrouter

Documentation
=============

See http://cdrouterpy.readthedocs.io/.
